@@ -7,14 +7,12 @@ setValidity(
   Class = "MeanDate",
   method = function(object) {
     # Get data
-    types <- object@types
-    weights <- object@weights
+    dates <- object@dates
     m <- nrow(weights)
-    p <- ncol(weights)
+    p <- ncol(object)
 
     cnd <- list(
-      arkhe::validate(arkhe::assert_length(object, m)),
-      arkhe::validate(arkhe::assert_length(types, p))
+      arkhe::validate(arkhe::assert_length(dates, p))
     )
 
     # Return cnd, if any
@@ -47,13 +45,9 @@ setValidity(
   Class = "AoristicSum",
   method = function(object) {
     # Get data
-    from <- object@from
-    to <- object@to
-    step <- object@step
     weights <- object@weights
     groups <- object@groups
     breaks <- object@breaks
-    blocks <- object@blocks
     p <- object@p
 
     i <- nrow(p)
@@ -61,13 +55,9 @@ setValidity(
     k <- length(unique(groups))
 
     cnd <- list(
-      arkhe::validate(arkhe::assert_length(from, i)),
-      arkhe::validate(arkhe::assert_length(to, i)),
-      arkhe::validate(arkhe::assert_scalar(step, "numeric")),
       arkhe::validate(arkhe::assert_length(weights, i)),
       arkhe::validate(arkhe::assert_length(groups, i)),
       arkhe::validate(arkhe::assert_length(breaks, j + 1)),
-      arkhe::validate(arkhe::assert_length(blocks, j)),
       arkhe::validate(arkhe::assert_dimensions(p, c(i, j, k)))
     )
 
@@ -82,7 +72,6 @@ setValidity(
   method = function(object) {
     # Get data
     replicates <- object@replicates
-    breaks <- object@breaks
     groups <- object@groups
 
     i <- nrow(object)
@@ -91,8 +80,7 @@ setValidity(
 
     cnd <- list(
       arkhe::validate(arkhe::assert_scalar(replicates, "integer")),
-      arkhe::validate(arkhe::assert_length(groups, k)),
-      arkhe::validate(arkhe::assert_length(breaks, j))
+      arkhe::validate(arkhe::assert_length(groups, k))
     )
 
     # Return cnd, if any
@@ -128,17 +116,13 @@ setValidity(
   Class = "IncrementTest",
   method = function(object) {
     # Get data
-    counts <- object@counts
-    dates <- object@dates
     statistic <- object@statistic
     parameter <- object@parameter
     p_value <- object@p_value
 
-    i <- nrow(counts)
-    j <- ncol(counts)
+    j <- ncol(object)
 
     cnd <- list(
-      arkhe::validate(arkhe::assert_length(dates, i)),
       arkhe::validate(arkhe::assert_length(statistic, j)),
       arkhe::validate(arkhe::assert_scalar(parameter, "integer")),
       arkhe::validate(arkhe::assert_length(p_value, j))
